PyXMake Developer Guide: PyXMake.Tools.ErrorHandling Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Classes
PyXMake.Tools.ErrorHandling Namespace Reference

Error handling module. More...

## Classes
class | Error
| Parent class inherited from built-in exception. More...
class | InputError
| Base class for all input errors. More...
class | TransitionError
| Base class for all transition errors. More...

## Detailed Description

Error handling module.

    Collection of custom errors and exceptions.

    @note: PyXMake module
    Created on 20.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  20.03.2018

Notes/Changes
  - Added documentation // mg 29.03.2018